==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/cdns/servers/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.cdns.servers', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.cdns.servers', {
				url: '/{cdnId}/servers',
				views: {
					cdnsContent: {
						templateUrl: 'common/modules/table/cdnServers/table.cdnServers.tpl.html',
						controller: 'TableCDNServersController',
						resolve: {
							cdn: function($stateParams, cdnService) {
								return cdnService.getCDN($stateParams.cdnId);
							},
							servers: function($stateParams, serverService) {
								return serverService.getServers({ cdn: $stateParams.cdnId, orderby: 'hostName' });
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_portal/app/src/modules/private/cdns/servers/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.cdns.servers', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.cdns.servers', {
				url: '/{cdnId}/servers',
				views: {
					cdnsContent: {
						templateUrl: 'common/modules/table/cdnServers/table.cdnServers.tpl.html',
						controller: 'TableCDNServersController',
						resolve: {
							cdn: function($stateParams, cdnService) {
								return cdnService.getCDN($stateParams.cdnId);
							},
							servers: function(cdn, $stateParams, serverService) {
								return serverService.getServers({ cdn: cdn.id, orderby: 'hostName' });
							},
							filter: function(cdn) {
								return {
									cdnName: {
										filterType: "text",
										type: "equals",
										filter: cdn.name
									}
								}
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
